@@ -37,6 +37,7 @@ class H2OXGBoost(H2OXGBoostParams, H2OTreeBasedSupervisedAlgorithm, Distribution
                  withContributions=False,
                  dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
+                 namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
                  detailedPredictionCol="detailed_prediction",
                  validationDataFrame=None,
@@ -68,7 +69,6 @@ class H2OXGBoost(H2OXGBoostParams, H2OTreeBasedSupervisedAlgorithm, Distribution
                  buildTreeOneNode=False,
                  saveMatrixDirectory=None,
                  calibrateModel=False,
-                 calibrationMethod="AUTO",
                  maxBins=256,
                  maxLeaves=0,
                  treeMethod="auto",
@@ -87,14 +87,11 @@ class H2OXGBoost(H2OXGBoostParams, H2OTreeBasedSupervisedAlgorithm, Distribution
                  gpuId=None,
                  interactionConstraints=None,
                  scalePosWeight=1.0,
-                 evalMetric=None,
-                 scoreEvalMetricOnly=False,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
                  keepCrossValidationPredictions=False,
                  keepCrossValidationFoldAssignment=False,
-                 parallelizeCrossValidation=True,
                  distribution="AUTO",
                  tweediePower=1.5,
                  labelCol="label",
