@@ -34,6 +34,7 @@ class H2OGBMRegressor(H2OGBM):
                  withContributions=False,
                  dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
+                 namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
                  detailedPredictionCol="detailed_prediction",
                  validationDataFrame=None,
@@ -68,10 +69,7 @@ class H2OGBMRegressor(H2OGBM):
                  minSplitImprovement=1.0E-5,
                  histogramType="AUTO",
                  calibrateModel=False,
-                 calibrationMethod="AUTO",
                  checkConstantResponse=True,
-                 inTrainingCheckpointsDir=None,
-                 inTrainingCheckpointsTreeInterval=1,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
